var servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange =
[
    [ "com::sun::star::sheet::XCellRangeReferrer", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html#aab7706bd0d8d10d44ac3c1d3b27af60e", null ],
    [ "com::sun::star::sheet::XNamedRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html#a3ff23a87e438a5954716ce16abf3045e", null ],
    [ "IsSharedFormula", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html#a0d0bc18272f715ac3fdd8176f7f0f929", null ],
    [ "TokenIndex", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html#aee82d26f89c26d9ec2530b7527c91574", null ]
];